package WebService::Braintree::CreditCard::Location;
$WebService::Braintree::CreditCard::Location::VERSION = '0.94';
use 5.010_001;
use strictures 1;

use constant International => "international";
use constant US => "us";

1;
__END__
